@@ -2,5 +2,5 @@
 #include <Rinternals.h>
 
 extern SEXP DASarrayFnCpp(SEXP nXbasisw, SEXP nWbasisw, SEXP nUbasisj, SEXP nAbasisj, 
-                          SEXP nrep,     SEXP BVECW,    SEXP UCOEFJ,   SEXP BATENS);
+                          SEXP BVECW,    SEXP UCOEFJ,   SEXP BATENS);
 
