@@ -3,7 +3,7 @@
 
 extern "C" {
   SEXP DBSarrayFnCpp(SEXP nXbasisw, SEXP nWbasisw, SEXP nUbasisj, SEXP nAbasisj,  
-                     SEXP nrep,     SEXP AVECJ,    SEXP UCOEFJ,   SEXP BATENS)
+                     SEXP AVECJ,    SEXP UCOEFJ,   SEXP BATENS)
   {
     int nDBSarray;
     SEXP DBSarray;
@@ -11,12 +11,11 @@ extern "C" {
     int nWw = *INTEGER(nWbasisw);
     int nUj = *INTEGER(nUbasisj);
     int nAj = *INTEGER(nAbasisj);
-    int nRp = *INTEGER(nrep);
     double* Avecj  = REAL(AVECJ);
     double* Ucoefj = REAL(UCOEFJ);
     double* BAtens = REAL(BATENS);
     double* rDBSarray;
-    nDBSarray = nXw*nRp*nWw;
+    nDBSarray = nXw*nWw;
     DBSarray  = PROTECT(allocVector(REALSXP, nDBSarray));
     rDBSarray = REAL(DBSarray);
     /* assign 0 to all positions */
@@ -25,21 +24,17 @@ extern "C" {
       rDBSarray[p]=0;
     }
     /* loop through all columns of all four input matrices */
-    for (int r = 0; r < nRp; r++)
+    for (int i = 0; i < nXw; i++)
     {
-      for (int i = 0; i < nXw; i++)
+      for (int j = 0; j < nWw; j++)
       {
-        for (int j = 0; j < nWw; j++)
+        for (int k = 0; k < nUj; k++)
         {
-          for (int k = 0; k < nUj; k++)
+          for (int l = 0; l < nAj; l++)
           {
-            for (int l = 0; l < nAj; l++)
-            {
-              int ijkl = i*nAj*nUj*nWw + j*nAj*nUj + k*nAj + l;
-              /*  increment value at index by the product */
-              rDBSarray[i+r*nXw+j*nRp*nXw] +=
-              Avecj[l] * Ucoefj[k+r*nUj] * BAtens[ijkl];
-            }
+            int ijkl = i*nAj*nUj*nWw + j*nAj*nUj + k*nAj + l;
+            /*  increment value at index by the product */
+            rDBSarray[i+j*nXw] += Avecj[l] * Ucoefj[k] * BAtens[ijkl];
           }
         }
       }
