@@ -2,4 +2,4 @@
 #include <Rinternals.h>
 
 extern SEXP DBSarrayFnCpp(SEXP nXbasisw, SEXP nWbasisw, SEXP nUbasisj, SEXP nAbasisj,  
-                          SEXP nrep,     SEXP AVECJ,    SEXP UCOEFJ,   SEXP BATENS);
+                          SEXP AVECJ,    SEXP UCOEFJ,   SEXP BATENS);
